@@ -274,13 +274,6 @@ lessonfile_functions = {
         'chordname': (False, lambda s: LabelObject("chordname", s)),
 }
 
-# We need this modified dict to use when parsing data into the
-# sqlite-database. This because we want those data to be in C-locale
-# so that the program can be run in different locales from the same
-# database.
-lessonfile_functions_no_i18n = dict(lessonfile_functions)
-lessonfile_functions_no_i18n['_'] = (False, lambda f: f)
-lessonfile_functions_no_i18n['_i'] = (False, lambda f: f)
 
 def rnc_markup_tokenizer(s):
     """
@@ -1427,7 +1420,10 @@ class TestSupport(object):
         pass the test. (values 0.0 to 1.0)
         """
         m = re.match("([\d\.]+)%", self.header.test_requirement)
-        return float(m.groups()[0])/100.0
+        if m:
+            return float(m.groups()[0])/100.0
+        else:
+            return 0.9
     def enter_test_mode(self):
         self.m_test_questions = self._generate_test_questions()
         self.m_test_idx = -1
@@ -1907,13 +1903,20 @@ class InfoCache(object):
                     except self.InfoCacheException:
                         logging.debug(" exception, not parsed: %s", fn)
                         pass
-    def iter_user_files(self):
+    def iter_user_files(self, only_user_collection=False):
         """
         Put the data from the lesson files below ~/.solfege/exercises/
         in the cache and yield the filename.
+        
+        If only_user_collection=True it will only iterate the lesson files
+        in .solfege/exercises/user/lesson-files
         """
-        logging.debug("iter_user_files()")
-        for fn in glob.glob(os.path.join(filesystem.user_data(), u"exercises/*/*/*")):
+        logging.debug("iter_user_files(%s)", only_user_collection)
+        if only_user_collection:
+            mask = u"user/lesson-files/*"
+        else:
+            mask = u"*/*/*"
+        for fn in glob.glob(os.path.join(filesystem.user_data(), u"exercises", mask)):
             if os.path.isfile(fn):
                 try:
                     self.parse_file(fn)
@@ -2031,7 +2034,7 @@ def parse_lesson_file_header(filename):
     # and must be updated there too if changed.
     s = open(filename, 'rU').read(40960)
     m = r.search(s)
-    p = dataparser.Dataparser(predef, lessonfile_functions_no_i18n)
+    p = dataparser.Dataparser(predef, lessonfile_functions)
     p.m_location = os.path.split(filename)
     p.m_ignore_lookup_error = True
     if not m:
